@@ -1,7 +1,3 @@
-import os
-import subprocess
-import sys
-
 import typer.core
 from typer.testing import CliRunner
 
@@ -37,18 +33,3 @@ def test_coverage_call():
     result = runner.invoke(mod.app)
     assert result.exit_code == 0
     assert "Hello John Doe, it seems you have 42" in result.output
-
-
-def test_completion():
-    result = subprocess.run(
-        [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        capture_output=True,
-        encoding="utf-8",
-        env={
-            **os.environ,
-            "_COMPAT_CLICK7_8.PY_COMPLETE": "complete_zsh",
-            "_TYPER_COMPLETE_ARGS": "compat_click7_8.py --nickname ",
-            "_TYPER_COMPLETE_TESTING": "True",
-        },
-    )
-    assert "Jonny" in result.stdout
